package com.ruoyi.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.PosAppeal;

import java.util.List;

/**
 * 留言信息Mapper接口
 * 
 * @author ruoyi
 * @date 2024-07-07
 */
public interface PosAppealMapper  extends BaseMapper<PosAppeal>
{
    /**
     * 查询留言信息
     * 
     * @param id 留言信息主键
     * @return 留言信息
     */
    public PosAppeal selectPosAppealById(Long id);

    /**
     * 查询留言信息列表
     * 
     * @param posAppeal 留言信息
     * @return 留言信息集合
     */
    public List<PosAppeal> selectPosAppealList(PosAppeal posAppeal);

    /**
     * 新增留言信息
     * 
     * @param posAppeal 留言信息
     * @return 结果
     */
    public int insertPosAppeal(PosAppeal posAppeal);

    /**
     * 修改留言信息
     * 
     * @param posAppeal 留言信息
     * @return 结果
     */
    public int updatePosAppeal(PosAppeal posAppeal);

    /**
     * 删除留言信息
     * 
     * @param id 留言信息主键
     * @return 结果
     */
    public int deletePosAppealById(Long id);

    /**
     * 批量删除留言信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePosAppealByIds(Long[] ids);
}
